@@ -4,7 +4,7 @@ from .utils.signal import signal
 # 存储 全局共享 数据
 GSTORE = {}
 
-def INFO(info:str):
+def INFO(info):
     """
     在日志和测试报告中打印 重要信息，
     使得 运行报告更加清晰
